==> xtlsapi-1.1.0.tar.gz: xtlsapi-1.1.0/HISTORY.md <==
Changelog
=========


(unreleased)
------------

New
~~~
- Update to xtls v7.5. [Your Name]

Other
~~~~~
- Merge pull request #5 from hoshython/patch-1. [Hiddify]

  Update utils.py
- Update utils.py. [hoshython]


1.0.14 (2023-01-22)
-------------------
- Release: version 1.0.14 🚀 [hiddify]
- Add statsquery. [hiddify]


1.0.13 (2023-01-22)
-------------------
- Release: version 1.0.13 🚀 [hiddify]
- Update protobuf version. [hiddify]


1.0.12 (2023-01-21)
-------------------
- Release: version 1.0.12 🚀 [hiddify]
- Fix issue. [hiddify]


1.0.11 (2023-01-20)
-------------------
- Release: version 1.0.11 🚀 [hiddify]
- Fix readme. [hiddify]


1.0.1 (2023-01-20)
------------------
- Release: version 1.0.1 🚀 [hiddify]
- Permission. [hiddify]


1.0.01 (2023-01-20)
-------------------
- Release: version 1.0.01 🚀 [hiddify]
- Fix readme. [hiddify]


1.0.0 (2023-01-20)
------------------
- Release: version 1.0.0 🚀 [hiddify]
- Remove test on macos and windows. [hiddify]
- Test xray api . it works fine. [hiddify]
- Merge pull request #1 from Iam54r1n4/fix-import-paths. [Hiddify]

  Fix import paths
- Fix more import path & test apis. [Iam54r1n4]
- Merge branch 'main' into fix-import-paths. [Iam54r1n4]
- Remove lint. [Hiddify]
- Add reference. [hiddify]
- Add xray grpc proto generator. [hiddify]
- Update grpc proto. [hiddify]
- Add usage code to README.md. [Iam54r1n4]
- Change client name & fix import path again. [Iam54r1n4]
- Fix added packages path. [Iam54r1n4]
- Add other packages. [Iam54r1n4]
- Fix import paths. [Iam54r1n4]
- Add xray_api grpc. [hiddify]
- ✅ Ready to clone and code. [hiddify]
- Initial commit. [Hiddify]

==> xtlsapi-2.0.0.tar.gz: xtlsapi-2.0.0/HISTORY.md <==
Changelog
=========


(unreleased)
------------

New
~~~
- Change default to vless. [hiddify]
- Add vless,trojan,shadowsocks account creatation. [hiddify]

Fix
~~~
- Typo. [hiddify]

Other
~~~~~
- Merge branch 'main' of github.com:hiddify/xtlsapi. [hiddify]


1.1.0 (2023-03-06)
------------------

New
~~~
- Update to xtls v7.5. [Your Name]

Other
~~~~~
- Release: version 1.1.0 🚀 [Your Name]
- Merge pull request #5 from hoshython/patch-1. [Hiddify]

  Update utils.py
- Update utils.py. [hoshython]


1.0.14 (2023-01-22)
-------------------
- Release: version 1.0.14 🚀 [hiddify]
- Add statsquery. [hiddify]


1.0.13 (2023-01-22)
-------------------
- Release: version 1.0.13 🚀 [hiddify]
- Update protobuf version. [hiddify]


1.0.12 (2023-01-21)
-------------------
- Release: version 1.0.12 🚀 [hiddify]
- Fix issue. [hiddify]


1.0.11 (2023-01-20)
-------------------
- Release: version 1.0.11 🚀 [hiddify]
- Fix readme. [hiddify]


1.0.1 (2023-01-20)
------------------
- Release: version 1.0.1 🚀 [hiddify]
- Permission. [hiddify]


1.0.01 (2023-01-20)
-------------------
- Release: version 1.0.01 🚀 [hiddify]
- Fix readme. [hiddify]


1.0.0 (2023-01-20)
------------------
- Release: version 1.0.0 🚀 [hiddify]
- Remove test on macos and windows. [hiddify]
- Test xray api . it works fine. [hiddify]
- Merge pull request #1 from Iam54r1n4/fix-import-paths. [Hiddify]

  Fix import paths
- Fix more import path & test apis. [Iam54r1n4]
- Merge branch 'main' into fix-import-paths. [Iam54r1n4]
- Remove lint. [Hiddify]
- Add reference. [hiddify]
- Add xray grpc proto generator. [hiddify]
- Update grpc proto. [hiddify]
- Add usage code to README.md. [Iam54r1n4]
- Change client name & fix import path again. [Iam54r1n4]
- Fix added packages path. [Iam54r1n4]
- Add other packages. [Iam54r1n4]
- Fix import paths. [Iam54r1n4]
- Add xray_api grpc. [hiddify]
- ✅ Ready to clone and code. [hiddify]
- Initial commit. [Hiddify]
